==> vtigercrm-5.3.0p0.tgz: modules/ProjectMilestone/language/de_de.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
/**
 * German tranlsation by mic [ http://www.joomlasupportdesk.com ] 2009.10.02
 * IMPORTANT: save file with UTF-8 without BOM!
 **/
$mod_strings = Array(
	 
	'LBL_MODULE_NAME'=>'Projektmeilensteine',
  	'LBL_MODULE_TITLE'=>'Projektmeilensteine',
	'LBL_NEW_OPERATION'=>'neuer Projektmeilenstein',
    'LBL_MILESTONES'=>'Projektmeilensteine',
    'LBL_MILESTONE'=>'Projektmeilenstein',
    'Project Milestone ID'=>'Meilenstein ID',
    'projectmilestones' => 'Projektmeilensteine',
    //added this to translate the module name in the main app menu
    'ProjectMilestone'=>'Projektmeilensteine',
    //
    'SINGLE_ProjectMilestone' => 'Projektmeilenstein',
    'LBL_CUSTOM_INFORMATION' => 'zusätzlich Information',
    'LBL_PROJECT_MILESTONE_INFORMATION' => 'Meilensteininformation',
    'LBL_DESCRIPTION_INFORMATION' => 'Beschreibung',
    'Assigned To' => 'zuständig',
    'Milestone Date' => 'Meilenstein Datum',
    'Milestone' => 'Meilenstein',
    'Type'=>'Typ',
    //'linktoproject'=>'Link To',
    'Related Project' => 'bezogenes Projekt',
    'Related To' => 'bezogen auf',
    'projectid' => 'bezogen auf',
  	'administrative' => 'administrativ',
    'operative' => 'operativ',
    'other' => 'andere',
    'Created Time' => 'erstellt',
    'Modified Time' => 'geändert',
    'description' => 'Beschreibung',
    'Description' => 'Beschreibung',
    //added for related lists 
    'Project Milestone Name' => 'Meilensteinname',
    'Project Milestone No' => 'Meilensteinnr.',

);

?>

==> vtigercrm-5.4.0.tgz: modules/ProjectMilestone/language/de_de.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$mod_strings = Array(
	 
	'LBL_MODULE_NAME'=>'Projektmeilensteine',
  	'LBL_MODULE_TITLE'=>'Projektmeilensteine',
	'LBL_NEW_OPERATION'=>'neuer Projektmeilenstein',
    'LBL_MILESTONES'=>'Projektmeilensteine',
    'LBL_MILESTONE'=>'Projektmeilenstein',
    'Project Milestone ID'=>'Meilenstein ID',
    'projectmilestones' => 'Projektmeilensteine',
    //added this to translate the module name in the main app menu
    'ProjectMilestone'=>'Projektmeilensteine',
    //
    'SINGLE_ProjectMilestone' => 'Projektmeilenstein',
    'LBL_CUSTOM_INFORMATION' => 'zusätzlich Information',
    'LBL_PROJECT_MILESTONE_INFORMATION' => 'Meilensteininformation',
    'LBL_DESCRIPTION_INFORMATION' => 'Beschreibung',
    'Assigned To' => 'zuständig',
    'Milestone Date' => 'Meilenstein Datum',
    'Milestone' => 'Meilenstein',
    'Type'=>'Typ',
    //'linktoproject'=>'Link To',
    'Related Project' => 'bezogenes Projekt',
    'Related To' => 'bezogen auf',
    'projectid' => 'bezogen auf',
  	'administrative' => 'administrativ',
    'operative' => 'operativ',
    'other' => 'andere',
    'Created Time' => 'erstellt',
    'Modified Time' => 'geändert',
    'description' => 'Beschreibung',
    'Description' => 'Beschreibung',
    //added for related lists 
    'Project Milestone Name' => 'Meilensteinname',
    'Project Milestone No' => 'Meilenstein Nr',
	'ProjectMilestone ID' => 'Meilenstein ID',
);

?>
